print('Imported successfully')
import pandas as pd

from IPython.core.display import HTML
from IPython.display import display
f = open('files/CSSv2.css','r')
HTML('<style>{}</style>'.format(f.read()))

import numpy as np
import matplotlib.pyplot as plt
import matplotlib as mpl
import seaborn as sns
import scipy.stats as sts
from IPython.display import display
import_dict = {'pandas':'pd',
                 'numpy':'np',
                 'matplotlib':'mpl',
                 'matplotlib.pyplot':'plt',
                 'seaborn':'sns',
                 'scip.stats.':'sts',
                 }
# index_range = list(range(1,len(import_dict)))
df_imported= pd.DataFrame.from_dict(import_dict,orient='index', columns=['Module/Package Handle'])
list_packages = df_imported.index
df_imported.reset_index(inplace=True)
df_imported.columns=['Imported Module/Package','Imported As']

display(df_imported)

function_list = ('list2df','df_drop_regex','viz_tree','performance_r2_mse','performance_roc_auc',
'performance_roc_auc','tune_params_trees','multiplot','plot_hist_scat_sns','detect_outliers','describe_outliers','Cohen_d',
'draw_violinplot','subplot_imshow','plot_wide_kde_thin_bar','confusion_matrix','scale_data')
excluded='plot_pdf'
function_series = pd.DataFrame(function_list,columns=['List of Available Functions'])
# function_series.Name='Package_Functions'
display(function_series)


   


# name = "JMI_MVM v0.1.3"
from startup import *
from functions import *



# help_ = print(f" Recommended Functions to try: \n tune_params_trees \n plot_hist_scat_sns & multiplot\n list2df & df_drop_regex\n plot_wide_kde_thin_bar & make_violinplot\n")
#functions.py
# import pandas as pd

# # List of Functions Included (plus abbrevs for imported packages i.e. sns, np, plt)
# import os.path
# import os
# import sys
# sys.path.append('') 
# sys.path.append(os.path.join(os.path.dirname(tools.py), '..'))


# df_functions = pd.DataFrame([x for x in dir() if '__' not in x])
# df_functions.columns=['Available_Functions']
# df_functions.set_index('Available_Functions',inplace=True)
# df_functions
# print("Imported the following:\n pandas (pd), numpy(np), matplotlib.pyplot(plt), matplotlib(mpl), seaborn(sns), IPython.display(display)")
